%define        majver %(echo %version | cut -d. -f1-2)
%define        serverdir     %(apxs -q htdocsdir 2>/dev/null)

# To create a customized installation of wordpress:
# autospec -u wordpress -a5 \
#   -d "installdir=%serverdir/../www.example.com, \
#       sitename=example, \
#       adminmail=webmaster@example.com"

%if "%{?installdir}" == ""
   %define     installdir    %{serverdir}/wordpress
%endif

%if "%{?sitename}" != ""
   %if "%{?servername}" == ""
      %define  servername    %(basename %installdir 2>/dev/null)
   %endif
   %define     serverlogdir  %(apxs -q logfiledir 2>/dev/null)
%else
   %if "%{?aliasdir}" == ""
      %define  aliasdir      /wordpress
   %endif
%endif

Name:          %{?sitename:%sitename-website-}wordpress
Version:       5.6
Release:       1mamba
Summary:       A semantic personal publishing platform
Group:         Applications/Web
Vendor:        openmamba
Distribution:  openmamba
Packager:      Stefano Cotta Ramusino <stefano.cotta@openmamba.org>
URL:           http://wordpress.org
Source:        http://wordpress.org/wordpress-%{version}.tar.gz
Source1:       wordpress-db-config
Source2:       wordpress-i18n-it_IT-%{majver}.zip
Source3:       wordpress-autoupdate
License:       GPL
BuildArch:     noarch
Requires:      apache-mod_php >= 4.2
Requires:      php-mysql
## AUTOBUILDREQ-BEGIN
## AUTOBUILDREQ-END
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
WordPress is a state-of-the-art semantic personal publishing platform with a focus on aesthetics, web standards, and usability. What a mouthful.
WordPress is both free and priceless at the same time.

More simply, WordPress is what you use when you want to work with your blogging software, not fight it.

%prep
%setup -q -n %{name}
mkdir -p wp-content/languages
pushd wp-content/languages
unzip -o %{S:2}
popd

find . -name '*~' -delete

%build
#pushd wp-content/languages
#msgfmt -o it.mo it*.po
#rm -f *.po
#popd

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
install -d %{buildroot}%{installdir}
cp -a * %{buildroot}%{installdir}/

rm -f %{buildroot}%{installdir}/{license.txt,readme.html}
mv %{buildroot}%{installdir}/wp-config-sample.php \
   %{buildroot}%{installdir}/wp-config.php

install -d %{buildroot}%{installdir}/config.d
install -m 0644 %{S:1} %{buildroot}%{installdir}/config.d/db.php
%if "%{?sitename}" != ""
cat > %{buildroot}%{installdir}/config.d/general.php << EOF
<?php

// The full URL of your wordPress install
\$bb->uri = 'http://%{servername}';

// What are you going to call me?
\$bb->name = '%{sitename} blog';

// This must be set before you run the install script.
\$bb->admin_email = '%{adminmail}';

?>
EOF
%endif

install -d %{buildroot}%{_sysconfdir}/httpd/httpd.d
%if "%{?sitename}" != ""
cat > %{buildroot}%{_sysconfdir}/httpd/httpd.d/%{servername}.conf << EOF
%else
cat > %{buildroot}%{_sysconfdir}/httpd/httpd.d/%{name}.conf << EOF
%endif
%if "%{?sitename}" == ""
%if "%(dirname %installdir)" != "%{serverdir}"
Alias %{aliasdir} %{installdir}

%endif
%endif
<Directory %{installdir}>
    AllowOverride Options
    Order allow,deny
    Allow from All
</Directory>
%if "%{?sitename}" != ""
%if "%(dirname %installdir)" != "%{serverdir}"

<VirtualHost *:80>
   %{?adminmail:ServerAdmin %adminmail}
   DocumentRoot %{installdir}
   ServerName %{servername}
   ErrorLog %{serverlogdir}/%{servername}-error_log
   CustomLog %{serverlogdir}/%{servername}-access_log common
</VirtualHost>
%endif
%endif
EOF

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post
if [ $1 -ge 1 ]; then
   service httpd condrestart
fi
:

%preun
if [ $1 -eq 0 ]; then
#erase
   service httpd condrestart
fi
:

%files
%defattr(-,root,root)
%if "%{?sitename}" != ""
%config(noreplace) %{_sysconfdir}/httpd/httpd.d/%{servername}.conf
%else
%config(noreplace) %{_sysconfdir}/httpd/httpd.d/%{name}.conf
%endif
%config(noreplace) %{installdir}/wp-config.php
%config(noreplace) %{installdir}/config.d/db.php
%if "%{?sitename}" != ""
%config(noreplace) %{installdir}/config.d/general.php
%endif
%dir %{installdir}
%{installdir}/*
%doc license.txt readme.html

%changelog
* Wed Dec 09 2020 Automatic Build System <autodist@mambasoft.it> 5.6-1mamba
- automatic version update by autodist

* Sat Oct 31 2020 Automatic Build System <autodist@mambasoft.it> 5.5.3-1mamba
- automatic version update by autodist

* Fri Oct 30 2020 Automatic Build System <autodist@mambasoft.it> 5.5.2-1mamba
- automatic version update by autodist

* Wed Sep 02 2020 Automatic Build System <autodist@mambasoft.it> 5.5.1-1mamba
- automatic version update by autodist

* Thu Aug 13 2020 Automatic Build System <autodist@mambasoft.it> 5.5-1mamba
- automatic version update by autodist

* Thu Jun 11 2020 Automatic Build System <autodist@mambasoft.it> 5.4.2-1mamba
- automatic version update by autodist

* Thu Apr 30 2020 Automatic Build System <autodist@mambasoft.it> 5.4.1-1mamba
- automatic version update by autodist

* Wed Apr 01 2020 Automatic Build System <autodist@mambasoft.it> 5.4-1mamba
- automatic version update by autodist

* Tue Dec 31 2019 Automatic Build System <autodist@mambasoft.it> 5.3.2-1mamba
- automatic version update by autodist

* Wed Nov 13 2019 Automatic Build System <autodist@mambasoft.it> 5.3-1mamba
- automatic version update by autodist

* Tue Oct 15 2019 Automatic Build System <autodist@mambasoft.it> 5.2.4-1mamba
- automatic version update by autodist

* Sat Sep 07 2019 Automatic Build System <autodist@mambasoft.it> 5.2.3-1mamba
- automatic version update by autodist

* Sat Jul 06 2019 Automatic Build System <autodist@mambasoft.it> 5.2.2-1mamba
- automatic version update by autodist

* Wed May 22 2019 Automatic Build System <autodist@mambasoft.it> 5.2.1-1mamba
- automatic version update by autodist

* Wed May 08 2019 Automatic Build System <autodist@mambasoft.it> 5.2-1mamba
- automatic version update by autodist

* Wed Mar 13 2019 Automatic Build System <autodist@mambasoft.it> 5.1.1-1mamba
- automatic version update by autodist

* Fri Feb 22 2019 Automatic Build System <autodist@mambasoft.it> 5.1-1mamba
- automatic version update by autodist

* Thu Jan 10 2019 Automatic Build System <autodist@mambasoft.it> 5.0.3-1mamba
- automatic version update by autodist

* Sun Dec 23 2018 Automatic Build System <autodist@mambasoft.it> 5.0.2-1mamba
- automatic version update by autodist

* Fri Dec 07 2018 Automatic Build System <autodist@mambasoft.it> 5.0-1mamba
- automatic version update by autodist

* Sat Aug 04 2018 Automatic Build System <autodist@mambasoft.it> 4.9.8-1mamba
- automatic version update by autodist

* Fri May 25 2018 Automatic Build System <autodist@mambasoft.it> 4.9.6-1mamba
- automatic version update by autodist

* Tue Apr 10 2018 Automatic Build System <autodist@mambasoft.it> 4.9.5-1mamba
- automatic version update by autodist

* Wed Feb 07 2018 Automatic Build System <autodist@mambasoft.it> 4.9.4-1mamba
- automatic version update by autodist

* Tue Feb 06 2018 Automatic Build System <autodist@mambasoft.it> 4.9.3-1mamba
- automatic version update by autodist

* Tue Jan 23 2018 Automatic Build System <autodist@mambasoft.it> 4.9.2-1mamba
- automatic version update by autodist

* Wed Dec 27 2017 Automatic Build System <autodist@mambasoft.it> 4.9.1-1mamba
- automatic version update by autodist

* Wed Nov 01 2017 Automatic Build System <autodist@mambasoft.it> 4.8.3-1mamba
- automatic version update by autodist

* Tue Sep 26 2017 Automatic Build System <autodist@mambasoft.it> 4.8.2-1mamba
- automatic version update by autodist

* Tue Aug 15 2017 Automatic Build System <autodist@mambasoft.it> 4.8.1-1mamba
- automatic version update by autodist

* Sat Aug 12 2017 Automatic Build System <autodist@mambasoft.it> 4.8-1mamba
- automatic version update by autodist

* Sat Jan 28 2017 Automatic Build System <autodist@mambasoft.it> 4.7.2-1mamba
- automatic version update by autodist

* Mon Jan 16 2017 Automatic Build System <autodist@mambasoft.it> 4.7.1-1mamba
- automatic version update by autodist

* Thu Dec 08 2016 Automatic Build System <autodist@mambasoft.it> 4.7-1mamba
- automatic version update by autodist

* Thu Sep 08 2016 Automatic Build System <autodist@mambasoft.it> 4.6.1-1mamba
- automatic version update by autodist

* Wed Aug 17 2016 Automatic Build System <autodist@mambasoft.it> 4.6-1mamba
- automatic version update by autodist

* Thu Jun 23 2016 Automatic Build System <autodist@mambasoft.it> 4.5.3-1mamba
- automatic version update by autodist

* Tue May 10 2016 Automatic Build System <autodist@mambasoft.it> 4.5.2-1mamba
- automatic version update by autodist

* Mon May 02 2016 Automatic Build System <autodist@mambasoft.it> 4.5.1-1mamba
- automatic version update by autodist

* Tue Apr 26 2016 Automatic Build System <autodist@mambasoft.it> 4.5-1mamba
- automatic version update by autodist

* Wed Feb 03 2016 Automatic Build System <autodist@mambasoft.it> 4.4.2-1mamba
- automatic version update by autodist

* Thu Jan 07 2016 Automatic Build System <autodist@mambasoft.it> 4.4.1-1mamba
- automatic version update by autodist

* Wed Dec 09 2015 Automatic Build System <autodist@mambasoft.it> 4.4-1mamba
- automatic version update by autodist

* Wed Sep 16 2015 Automatic Build System <autodist@mambasoft.it> 4.3.1-1mamba
- automatic version update by autodist

* Mon Aug 24 2015 Automatic Build System <autodist@mambasoft.it> 4.3-1mamba
- automatic version update by autodist

* Wed Aug 05 2015 Automatic Build System <autodist@mambasoft.it> 4.2.4-1mamba
- automatic version update by autodist

* Thu Jul 23 2015 Automatic Build System <autodist@mambasoft.it> 4.2.3-1mamba
- automatic version update by autodist

* Sat Jun 06 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 4.2.2-2mamba
- update it_IT translations, add autoupdate file

* Thu May 07 2015 Automatic Build System <autodist@mambasoft.it> 4.2.2-1mamba
- automatic version update by autodist

* Wed Apr 22 2015 Automatic Build System <autodist@mambasoft.it> 4.1.2-1mamba
- automatic version update by autodist

* Thu Feb 19 2015 Automatic Build System <autodist@mambasoft.it> 4.1.1-1mamba
- automatic version update by autodist

* Sat Dec 20 2014 Automatic Build System <autodist@mambasoft.it> 4.1-1mamba
- automatic version update by autodist

* Fri Nov 21 2014 Automatic Build System <autodist@mambasoft.it> 4.0.1-1mamba
- automatic version update by autodist

* Sun Sep 14 2014 Automatic Build System <autodist@mambasoft.it> 4.0-1mamba
- automatic version update by autodist

* Thu Aug 07 2014 Automatic Build System <autodist@mambasoft.it> 3.9.2-1mamba
- automatic version update by autodist

* Fri May 09 2014 Automatic Build System <autodist@mambasoft.it> 3.9.1-1mamba
- automatic version update by autodist

* Fri Apr 18 2014 Automatic Build System <autodist@mambasoft.it> 3.9-1mamba
- automatic version update by autodist

* Tue Apr 15 2014 Automatic Build System <autodist@mambasoft.it> 3.8.3-1mamba
- automatic version update by autodist

* Wed Apr 09 2014 Automatic Build System <autodist@mambasoft.it> 3.8.2-1mamba
- automatic version update by autodist

* Fri Jan 24 2014 Automatic Build System <autodist@mambasoft.it> 3.8.1-1mamba
- automatic version update by autodist

* Sat Dec 14 2013 Automatic Build System <autodist@mambasoft.it> 3.8-1mamba
- automatic version update by autodist

* Wed Oct 30 2013 Automatic Build System <autodist@mambasoft.it> 3.7.1-1mamba
- automatic version update by autodist

* Sat Oct 26 2013 Automatic Build System <autodist@mambasoft.it> 3.7-1mamba
- automatic version update by autodist

* Mon Sep 16 2013 Automatic Build System <autodist@mambasoft.it> 3.6.1-1mamba
- update to 3.6.1

* Sat Aug 10 2013 Automatic Build System <autodist@mambasoft.it> 3.6-1mamba
- automatic version update by autodist

* Wed Jul 17 2013 Automatic Build System <autodist@mambasoft.it> 3.5.2-1mamba
- automatic version update by autodist

* Mon Feb 25 2013 Automatic Build System <autodist@mambasoft.it> 3.5.1-1mamba
- automatic version update by autodist

* Fri Sep 07 2012 Automatic Build System <autodist@mambasoft.it> 3.4.2-1mamba
- automatic version update by autodist

* Thu Jun 28 2012 Automatic Build System <autodist@mambasoft.it> 3.4.1-1mamba
- automatic version update by autodist

* Thu Jun 14 2012 Automatic Build System <autodist@mambasoft.it> 3.4-1mamba
- automatic version update by autodist

* Sat Apr 21 2012 Automatic Build System <autodist@mambasoft.it> 3.3.2-1mamba
- automatic version update by autodist

* Wed Jan 04 2012 Automatic Build System <autodist@mambasoft.it> 3.3.1-1mamba
- automatic version update by autodist

* Tue Dec 13 2011 Automatic Build System <autodist@mambasoft.it> 3.3-1mamba
- automatic version update by autodist

* Wed Jul 13 2011 Automatic Build System <autodist@mambasoft.it> 3.2.1-1mamba
- automatic update by autodist

* Tue Jul 05 2011 Automatic Build System <autodist@mambasoft.it> 3.2-1mamba
- automatic update by autodist

* Sat Jul 02 2011 Automatic Build System <autodist@mambasoft.it> 3.1.4-1mamba
- automatic update by autodist

* Thu May 26 2011 Automatic Build System <autodist@mambasoft.it> 3.1.3-1mamba
- automatic update by autodist

* Wed Apr 27 2011 Automatic Build System <autodist@mambasoft.it> 3.1.2-1mamba
- automatic update by autodist

* Wed Apr 06 2011 Automatic Build System <autodist@mambasoft.it> 3.1.1-1mamba
- automatic update by autodist

* Thu Feb 24 2011 Automatic Build System <autodist@mambasoft.it> 3.1-1mamba
- automatic update by autodist

* Tue Feb 08 2011 Automatic Build System <autodist@mambasoft.it> 3.0.5-1mamba
- automatic update by autodist

* Thu Dec 30 2010 Automatic Build System <autodist@mambasoft.it> 3.0.4-1mamba
- automatic update by autodist

* Thu Dec 09 2010 Automatic Build System <autodist@mambasoft.it> 3.0.3-1mamba
- automatic update to 3.0.3 by autodist

* Wed Dec 01 2010 Automatic Build System <autodist@mambasoft.it> 3.0.2-1mamba
- automatic update to 3.0.2 by autodist

* Fri Jul 30 2010 Automatic Build System <autodist@mambasoft.it> 3.0.1-1mamba
- automatic update to 3.0.1 by autodist

* Fri Jun 25 2010 Automatic Build System <autodist@mambasoft.it> 3.0-1mamba
- automatic update by autodist

* Wed Apr 14 2010 Automatic Build System <autodist@mambasoft.it> 2.9.2-1mamba
- automatic update by autodist

* Wed Dec 23 2009 Automatic Build System <autodist@mambasoft.it> 2.9-1mamba
- automatic update by autodist

* Thu Nov 19 2009 Automatic Build System <autodist@mambasoft.it> 2.8.6-1mamba
- automatic update by autodist

* Tue Aug 18 2009 Automatic Build System <autodist@mambasoft.it> 2.8.4-1mamba
- automatic update by autodist

* Thu Aug 06 2009 Automatic Build System <autodist@mambasoft.it> 2.8.3-1mamba
- automatic update by autodist

* Fri Jul 24 2009 Automatic Build System <autodist@mambasoft.it> 2.8.2-1mamba
- automatic update by autodist

* Sun Jul 12 2009 Automatic Build System <autodist@mambasoft.it> 2.8.1-1mamba
- automatic update by autodist

* Fri Jun 19 2009 Automatic Build System <autodist@mambasoft.it> 2.8-1mamba
- automatic update by autodist

* Fri Feb 13 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7.1-2mamba
- added italian translation

* Fri Feb 13 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7.1-1mamba
- update to 2.7.1

* Mon Dec 22 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7-1mamba
- automatic update by autodist

* Wed Oct 01 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.2-1mamba
- automatic update by autodist

* Mon May 21 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.2-1mamba
- package created by autospec
